@@ -14,7 +14,7 @@ class ArtistModel: AudioCollectionModel {
 
     var sortModel = SortModel([.alpha])
 
-    var updateView: (() -> Void)?
+    var observable = Observable<MediaLibraryBaseModelObserver>()
 
     var files = [VLCMLArtist]()
 
@@ -26,13 +26,40 @@ class ArtistModel: AudioCollectionModel {
 
     required init(medialibrary: MediaLibraryService) {
         self.medialibrary = medialibrary
-        medialibrary.addObserver(self)
+        medialibrary.observable.addObserver(self)
         files = medialibrary.artists()
     }
 
     func append(_ item: VLCMLArtist) {
         files.append(item)
     }
+
+    private func addNewArtists(_ artists: [VLCMLArtist]) {
+        let newArtists = artists.filter() {
+            for artist in files {
+                if artist.identifier() == $0.identifier() {
+                    return false
+                }
+            }
+            return true
+        }
+
+        for artist in newArtists {
+            if !files.contains(where: { $0.identifier() == artist.identifier() }) {
+                files.append(artist)
+            }
+        }
+    }
+
+    private func filterGeneratedArtists() {
+        for (index, artist) in files.enumerated() {
+            if artist.identifier() == UnknownArtistID || artist.identifier() == VariousArtistID {
+                if artist.tracksCount() == 0 {
+                    files.remove(at: index)
+                }
+            }
+        }
+    }
 }
 
 // MARK: - Sort
@@ -41,7 +68,9 @@ extension ArtistModel {
         files = medialibrary.artists(sortingCriteria: criteria, desc: desc)
         sortModel.currentSort = criteria
         sortModel.desc = desc
-        updateView?()
+        observable.observers.forEach() {
+            $0.value.observer?.mediaLibraryBaseModelReloadView()
+        }
     }
 }
 
@@ -57,14 +86,18 @@ extension VLCMLArtist: SearchableMLModel {
 extension ArtistModel: MediaLibraryObserver {
     func medialibrary(_ medialibrary: MediaLibraryService, didAddArtists artists: [VLCMLArtist]) {
         artists.forEach({ append($0) })
-        updateView?()
+        observable.observers.forEach() {
+            $0.value.observer?.mediaLibraryBaseModelReloadView()
+        }
     }
 
     func medialibrary(_ medialibrary: MediaLibraryService,
                       didModifyArtistsWithIds artistsIds: [NSNumber]) {
+
+        let uniqueArtistsIds = Array(Set(artistsIds))
         var artists = [VLCMLArtist]()
 
-        artistsIds.forEach() {
+        uniqueArtistsIds.forEach() {
             guard let safeArtist = medialibrary.medialib.artist(withIdentifier: $0.int64Value)
                 else {
                     return
@@ -73,14 +106,20 @@ extension ArtistModel: MediaLibraryObserver {
         }
 
         files = swapModels(with: artists)
-        updateView?()
+        addNewArtists(artists)
+        filterGeneratedArtists()
+        observable.observers.forEach() {
+            $0.value.observer?.mediaLibraryBaseModelReloadView()
+        }
     }
 
     func medialibrary(_ medialibrary: MediaLibraryService, didDeleteArtistsWithIds artistsIds: [NSNumber]) {
         files.removeAll {
             artistsIds.contains(NSNumber(value: $0.identifier()))
         }
-        updateView?()
+        observable.observers.forEach() {
+            $0.value.observer?.mediaLibraryBaseModelReloadView()
+        }
     }
 
     func medialibraryDidStartRescan() {
